<?php 

namespace Elementor;
 
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Popular Posts
class newspotrika_Widget_Popular_Posts extends Widget_Base {
 
   public function get_name() {
      return 'cc_popular_posts';
   }
 
   public function get_title() {
      return esc_html__( 'Popular Posts', 'newspotrika' );
   }
 
   public function get_icon() { 
        return 'eicon-archive-title';
   }
 
   public function get_categories() {
      return [ 'newspotrika-elements' ];
   }      

   protected function _register_controls() {
      
      $this->start_controls_section(
         'popular_posts_section',
         [
            'label' => esc_html__( 'Block Carousel', 'newspotrika' ),
            'type' => Controls_Manager::SECTION,
         ]
      );

      $this->add_control(
         'title',
         [
            'label' => esc_html__( 'Title', 'newspotrika' ),
            'type' => Controls_Manager::TEXT,
         ]
      );
      
      $this->add_control(
         'order',
         [
            'label' => esc_html__( 'Order', 'newspotrika' ),
            'type' => Controls_Manager::SELECT,
            'title' => __( 'Order', 'newspotrika' ),
            'options' => [
               'DESC'  => __( 'Descending', 'newspotrika' ),
               'ASC' => __( 'Ascending', 'newspotrika' )
            ],
            'default' => 'DESC',
         ]
      );

      $this->add_control(
         'posts_per_block',
         [
            'label' => esc_html__( 'Post Per Block', 'newspotrika' ),
            'type' => Controls_Manager::NUMBER,
            'default' => 5,
         ]
      );

      $this->add_control(
         'num_title_word',
         [
            'label' => __( 'Title Word Length', 'newspotrika' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'default' => 8,
         ]
      );

      $this->end_controls_section();
   }
   
 
   protected function render( $instance = [] ) {
 
        // get our input from the widget settings.
        $settings = $this->get_settings_for_display(); ?>


         <div class="popular_posts">
            <?php
            if ( $settings['title'] ) : ?>
               <div class="block-title">
                  <p><?php echo esc_html( $settings['title'] ) ?></p>
               </div>               
            <?php endif;?>
             <?php

             $popular_post = new \WP_Query(array(
                 'posts_per_page' => $settings['posts_per_block'],
                 'meta_key'=>'popular_posts',
                 'orderby'=>'meta_value_num',
                 'order'=> $settings['order'],
                 'ignore_sticky_posts' => true
             ));

             while($popular_post->have_posts()) : $popular_post->the_post();  ?>

               <div class="block-item">
                  <div class="block-list-row">
                     <div class="block-list-image">
                        <?php newspotrika_thumbnail('newspotrika-218x150')?>
                     </div>
                     <div class="block-list-content">
                        <a href="<?php the_permalink() ?>">
                           <h6>
                              <?php echo esc_html( wp_trim_words( get_the_title(), $settings['num_title_word'],' ')); ?>
                           </h6>                                 
                        </a>  
                        <ul class="list-inline block-item-list-meta">
                           <li class="list-inline-item">
                              <i class="fa fa-clock-o"></i><?php echo get_the_date(); ?>
                           </li> 
                           <li class="list-inline-item">
                              <a href="<?php comments_link(); ?>"><i class="fa fa-comment-o"></i><?php echo esc_html(get_comments_number()) ?></a>
                           </li> 
                        </ul>
                     </div>
                  </div>
               </div>

             <?php endwhile;
            wp_reset_postdata(); ?>
      </div> <!-- end popular_posts -->
   <?php

   }
 
}

Plugin::instance()->widgets_manager->register_widget_type( new newspotrika_Widget_Popular_Posts );